(simtelarray)=

# sim_telarray

Support modules for running sim_telarray.

## simtel_config_reader

(simtel-config-reader-1)=

```{eval-rst}
.. automodule:: simtel.simtel_config_reader
   :members:
```

## simtel_config_writer

(simtel-config-writer-1)=

```{eval-rst}
.. automodule:: simtel.simtel_config_writer
   :members:
```

## simtel_table_reader

(simtel-table-reader-1)=

```{eval-rst}
.. automodule:: simtel.simtel_table_reader
   :members:
```

## simtel_io_event_reader

(simtel_io_event_reader-1)=

```{eval-rst}
.. automodule:: simtel.simtel_io_event_reader
   :members:
```

## simtel_io_event_writer

(simtel_io_event_writer-1)=

```{eval-rst}
.. automodule:: simtel.simtel_io_event_writer
   :members:
```

## simtel_io_event_histograms

```{eval-rst}
.. automodule:: simtel.simtel_io_event_histograms
   :members:
```

## simtel_io_metadata

(simtel-io-metadata-1)=

```{eval-rst}
.. automodule:: simtel.simtel_io_metadata
   :members:
```

## simtel_io_file_info

(simtel-io-file-info-1)=

```{eval-rst}
.. automodule:: simtel.simtel_io_file_info
   :members:
```

## simulator_array

(simulate-array-1)=

```{eval-rst}
.. automodule:: simtel.simulator_array
   :members:
```

## simulator_camera_efficiency

(simulate-camera-efficiency-1)=

```{eval-rst}
.. automodule:: simtel.simulator_camera_efficiency
   :members:
```

## simulator_light_emission

(simulate-light-1)=

```{eval-rst}
.. automodule:: simtel.simulator_light_emission
   :members:
```

## simulator_ray_tracing

(simulate-ray-tracing-1)=

```{eval-rst}
.. automodule:: simtel.simulator_ray_tracing
   :members:
```
